@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2008 Kenneth J. Pronovici.
+# Copyright (c) 2004-2008,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: stage.py 925 2008-10-06 02:38:13Z pronovic $
+# Revision : $Id: stage.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Implements the standard 'stage' action.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -54,7 +54,7 @@ import logging
 
 # Cedar Backup modules
 from CedarBackup2.peer import RemotePeer, LocalPeer
-from CedarBackup2.util import getUidGid, changeOwnership, isStartOfWeek
+from CedarBackup2.util import getUidGid, changeOwnership, isStartOfWeek, isRunningAsRoot
 from CedarBackup2.actions.constants import DIR_TIME_FORMAT, STAGE_INDICATOR
 from CedarBackup2.actions.util import writeIndicatorFile
 
@@ -120,7 +120,7 @@ def executeStage(configPath, options, config):
          continue
       logger.debug("Found collect indicator.")
       targetDir = stagingDirs[peer.name]
-      if os.getuid() == 0:
+      if isRunningAsRoot():
          # Since we're running as root, we can change ownership
          ownership = getUidGid(config.options.backupUser,  config.options.backupGroup)
          logger.debug("Using target dir [%s], ownership [%d:%d]." % (targetDir, ownership[0], ownership[1]))
@@ -319,7 +319,7 @@ def _getLocalUser(config):
    @param config: Config object.
    @return: Name of local user that should be used
    """
-   if os.getuid() != 0:
+   if not isRunningAsRoot():
       return None
    return config.options.backupUser
 
