@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2007 Kenneth J. Pronovici.
+# Copyright (c) 2004-2007,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: store.py 750 2007-03-26 01:10:11Z pronovic $
+# Revision : $Id: store.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Implements the standard 'store' action.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -57,7 +57,7 @@ import tempfile
 
 # Cedar Backup modules
 from CedarBackup2.filesystem import compareContents
-from CedarBackup2.util import isStartOfWeek, getUidGid, changeOwnership
+from CedarBackup2.util import isStartOfWeek
 from CedarBackup2.util import mount, unmount, displayBytes
 from CedarBackup2.actions.util import createWriter, checkMediaState, buildMediaLabel, writeIndicatorFile
 from CedarBackup2.actions.constants import DIR_TIME_FORMAT, STAGE_INDICATOR, STORE_INDICATOR
@@ -362,11 +362,11 @@ def _findCorrectDailyDir(options, config):
    """
    oneDay = datetime.timedelta(days=1)
    today = datetime.date.today()
-   yesterday = today - oneDay;
-   tomorrow = today + oneDay;
-   todayDate = today.strftime(DIR_TIME_FORMAT);
-   yesterdayDate = yesterday.strftime(DIR_TIME_FORMAT);
-   tomorrowDate = tomorrow.strftime(DIR_TIME_FORMAT);
+   yesterday = today - oneDay
+   tomorrow = today + oneDay
+   todayDate = today.strftime(DIR_TIME_FORMAT)
+   yesterdayDate = yesterday.strftime(DIR_TIME_FORMAT)
+   tomorrowDate = tomorrow.strftime(DIR_TIME_FORMAT)
    todayPath = os.path.join(config.stage.targetDir, todayDate)
    yesterdayPath = os.path.join(config.stage.targetDir, yesterdayDate)
    tomorrowPath = os.path.join(config.stage.targetDir, tomorrowDate)
