@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2006-2007 Kenneth J. Pronovici.
+# Copyright (c) 2006-2007,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: mbox.py 761 2007-07-05 03:04:54Z pronovic $
+# Revision : $Id: mbox.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Provides an extension to back up mbox email files.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -173,18 +173,18 @@ class MboxFile(object):
       """
       if other is None:
          return 1
-      if self._absolutePath != other._absolutePath:
-         if self._absolutePath < other._absolutePath:
+      if self.absolutePath != other.absolutePath:
+         if self.absolutePath < other.absolutePath:
             return -1
          else:
             return 1
-      if self._collectMode != other._collectMode:
-         if self._collectMode < other._collectMode:
+      if self.collectMode != other.collectMode:
+         if self.collectMode < other.collectMode:
             return -1
          else:
             return 1
-      if self._compressMode != other._compressMode:
-         if self._compressMode < other._compressMode:
+      if self.compressMode != other.compressMode:
+         if self.compressMode < other.compressMode:
             return -1
          else:
             return 1
@@ -317,28 +317,28 @@ class MboxDir(object):
       """
       if other is None:
          return 1
-      if self._absolutePath != other._absolutePath:
-         if self._absolutePath < other._absolutePath:
+      if self.absolutePath != other.absolutePath:
+         if self.absolutePath < other.absolutePath:
             return -1
          else:
             return 1
-      if self._collectMode != other._collectMode:
-         if self._collectMode < other._collectMode:
+      if self.collectMode != other.collectMode:
+         if self.collectMode < other.collectMode:
             return -1
          else:
             return 1
-      if self._compressMode != other._compressMode:
-         if self._compressMode < other._compressMode:
+      if self.compressMode != other.compressMode:
+         if self.compressMode < other.compressMode:
             return -1
          else:
             return 1
-      if self._relativeExcludePaths != other._relativeExcludePaths:
-         if self._relativeExcludePaths < other._relativeExcludePaths:
+      if self.relativeExcludePaths != other.relativeExcludePaths:
+         if self.relativeExcludePaths < other.relativeExcludePaths:
             return -1
          else:
             return 1
-      if self._excludePatterns != other._excludePatterns:
-         if self._excludePatterns < other._excludePatterns:
+      if self.excludePatterns != other.excludePatterns:
+         if self.excludePatterns < other.excludePatterns:
             return -1
          else:
             return 1
@@ -521,23 +521,23 @@ class MboxConfig(object):
       """
       if other is None:
          return 1
-      if self._collectMode != other._collectMode:
-         if self._collectMode < other._collectMode:
+      if self.collectMode != other.collectMode:
+         if self.collectMode < other.collectMode:
             return -1
          else:
             return 1
-      if self._compressMode != other._compressMode:
-         if self._compressMode < other._compressMode:
+      if self.compressMode != other.compressMode:
+         if self.compressMode < other.compressMode:
             return -1
          else:
             return 1
-      if self._mboxFiles != other._mboxFiles:
-         if self._mboxFiles < other._mboxFiles:
+      if self.mboxFiles != other.mboxFiles:
+         if self.mboxFiles < other.mboxFiles:
             return -1
          else:
             return 1
-      if self._mboxDirs != other._mboxDirs:
-         if self._mboxDirs < other._mboxDirs:
+      if self.mboxDirs != other.mboxDirs:
+         if self.mboxDirs < other.mboxDirs:
             return -1
          else:
             return 1
@@ -719,8 +719,8 @@ class LocalConfig(object):
       """
       if other is None:
          return 1
-      if self._mbox != other._mbox:
-         if self._mbox < other._mbox:
+      if self.mbox != other.mbox:
+         if self.mbox < other.mbox:
             return -1
          else:
             return 1
@@ -833,6 +833,7 @@ class LocalConfig(object):
       (xmlDom, parentNode) = createInputDom(xmlData)
       self._mbox = LocalConfig._parseMbox(parentNode)
 
+   @staticmethod
    def _parseMbox(parent):
       """
       Parses an mbox configuration section.
@@ -865,8 +866,8 @@ class LocalConfig(object):
          mbox.mboxFiles = LocalConfig._parseMboxFiles(section)
          mbox.mboxDirs = LocalConfig._parseMboxDirs(section)
       return mbox
-   _parseMbox = staticmethod(_parseMbox)
 
+   @staticmethod
    def _parseMboxFiles(parent):
       """
       Reads a list of C{MboxFile} objects from immediately beneath the parent.
@@ -893,8 +894,8 @@ class LocalConfig(object):
       if lst == []:
          lst = None
       return lst
-   _parseMboxFiles = staticmethod(_parseMboxFiles)
 
+   @staticmethod
    def _parseMboxDirs(parent):
       """
       Reads a list of C{MboxDir} objects from immediately beneath the parent.
@@ -930,8 +931,8 @@ class LocalConfig(object):
       if lst == []:
          lst = None
       return lst
-   _parseMboxDirs = staticmethod(_parseMboxDirs)
 
+   @staticmethod
    def _parseExclusions(parentNode):
       """
       Reads exclusions data from immediately beneath the parent.
@@ -955,8 +956,8 @@ class LocalConfig(object):
          relative = readStringList(section, "rel_path")
          patterns = readStringList(section, "pattern")
          return (relative, patterns)
-   _parseExclusions = staticmethod(_parseExclusions)
 
+   @staticmethod
    def _addMboxFile(xmlDom, parentNode, mboxFile):
       """
       Adds an mbox file container as the next child of a parent.
@@ -982,8 +983,8 @@ class LocalConfig(object):
          addStringNode(xmlDom, sectionNode, "abs_path", mboxFile.absolutePath)
          addStringNode(xmlDom, sectionNode, "collect_mode", mboxFile.collectMode)
          addStringNode(xmlDom, sectionNode, "compress_mode", mboxFile.compressMode)
-   _addMboxFile = staticmethod(_addMboxFile)
 
+   @staticmethod
    def _addMboxDir(xmlDom, parentNode, mboxDir):
       """
       Adds an mbox directory container as the next child of a parent.
@@ -1023,7 +1024,6 @@ class LocalConfig(object):
             if mboxDir.excludePatterns is not None:
                for pattern in mboxDir.excludePatterns:
                   addStringNode(xmlDom, excludeNode, "pattern", pattern)
-   _addMboxDir = staticmethod(_addMboxDir)
 
 
 ########################################################################
