@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2006 Kenneth J. Pronovici.
+# Copyright (c) 2006,2010 Kenneth J. Pronovici.
 # Copyright (c) 2006 Antoine Beaupre.
 # All rights reserved.
 #
@@ -27,9 +27,9 @@
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 #            Antoine Beaupre <anarcat@koumbit.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: postgresql.py 570 2006-06-24 20:29:45Z pronovic $
+# Revision : $Id: postgresql.py 1022 2011-10-11 23:27:49Z pronovic $
 # Purpose  : Provides an extension to back up PostgreSQL databases.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -84,8 +84,8 @@ from bz2 import BZ2File
 
 # Cedar Backup modules
 from CedarBackup2.xmlutil import createInputDom, addContainerNode, addStringNode, addBooleanNode
-from CedarBackup2.xmlutil import readChildren, readFirstChild, readString, readStringList, readBoolean
-from CedarBackup2.config import VALID_COLLECT_MODES, VALID_COMPRESS_MODES
+from CedarBackup2.xmlutil import readFirstChild, readString, readStringList, readBoolean
+from CedarBackup2.config import VALID_COMPRESS_MODES
 from CedarBackup2.util import resolveCommand, executeCommand
 from CedarBackup2.util import ObjectTypeList, changeOwnership
 
@@ -120,7 +120,7 @@ class PostgresqlConfig(object):
    @sort: __init__, __repr__, __str__, __cmp__, user, all, databases
    """
 
-   def __init__(self, user=None, compressMode=None, all=None, databases=None):
+   def __init__(self, user=None, compressMode=None, all=None, databases=None):  # pylint: disable=W0622
       """
       Constructor for the C{PostgresqlConfig} class.
       
@@ -158,23 +158,23 @@ class PostgresqlConfig(object):
       """
       if other is None:
          return 1
-      if self._user != other._user:
-         if self._user < other._user:
+      if self.user != other.user:
+         if self.user < other.user:
             return -1
          else:
             return 1
-      if self._compressMode != other._compressMode:
-         if self._compressMode < other._compressMode:
+      if self.compressMode != other.compressMode:
+         if self.compressMode < other.compressMode:
             return -1
          else:
             return 1
-      if self._all != other._all:
-         if self._all < other._all:
+      if self.all != other.all:
+         if self.all < other.all:
             return -1
          else:
             return 1
-      if self._databases != other._databases:
-         if self._databases < other._databases:
+      if self.databases != other.databases:
+         if self.databases < other.databases:
             return -1
          else:
             return 1
@@ -350,8 +350,8 @@ class LocalConfig(object):
       """
       if other is None:
          return 1
-      if self._postgresql != other._postgresql:
-         if self._postgresql < other._postgresql:
+      if self.postgresql != other.postgresql:
+         if self.postgresql < other.postgresql:
             return -1
          else:
             return 1
@@ -444,6 +444,7 @@ class LocalConfig(object):
       (xmlDom, parentNode) = createInputDom(xmlData)
       self._postgresql = LocalConfig._parsePostgresql(parentNode)
 
+   @staticmethod
    def _parsePostgresql(parent):
       """
       Parses a postgresql configuration section.
@@ -473,7 +474,6 @@ class LocalConfig(object):
          postgresql.all = readBoolean(section, "all")
          postgresql.databases = readStringList(section, "database")
       return postgresql
-   _parsePostgresql = staticmethod(_parsePostgresql)
 
 
 ########################################################################
