@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2007,2010 Kenneth J. Pronovici.
+# Copyright (c) 2007,2010,2013 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: split.py 1023 2011-10-11 23:44:50Z pronovic $
+# Revision : $Id: split.py 1028 2013-03-21 14:33:51Z pronovic $
 # Purpose  : Provides an extension to split up large files in staging directories.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -482,7 +482,7 @@ def _splitFile(sourcePath, splitSize, backupUser, backupGroup, removeSource=Fals
       (result, output) = executeCommand(command, args, returnOutput=True, ignoreStderr=False)
       if result != 0:
          raise IOError("Error [%d] calling split for [%s]." % (result, sourcePath))
-      pattern = re.compile(r"(creating file `)(%s)(.*)(')" % prefix)
+      pattern = re.compile(r"(creating file [`'])(%s)(.*)(')" % prefix)
       match = pattern.search(output[-1:][0])
       if match is None:
          raise IOError("Unable to parse output from split command.")
