@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2005,2007 Kenneth J. Pronovici.
+# Copyright (c) 2005,2007,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: subversion.py 935 2009-03-29 18:56:50Z pronovic $
+# Revision : $Id: subversion.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Provides an extension to back up Subversion repositories.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -37,7 +37,7 @@
 ########################################################################
 
 """
-Provides an extension to back up Subversion databases.
+Provides an extension to back up Subversion repositories.
 
 This is a Cedar Backup extension used to back up Subversion repositories via
 the Cedar Backup command line.  Each Subversion repository can be backed using
@@ -173,33 +173,33 @@ class RepositoryDir(object):
       """
       if other is None:
          return 1
-      if self._repositoryType != other._repositoryType:
-         if self._repositoryType < other._repositoryType:
+      if self.repositoryType != other.repositoryType:
+         if self.repositoryType < other.repositoryType:
             return -1
          else:
             return 1
-      if self._directoryPath != other._directoryPath:
-         if self._directoryPath < other._directoryPath:
+      if self.directoryPath != other.directoryPath:
+         if self.directoryPath < other.directoryPath:
             return -1
          else:
             return 1
-      if self._collectMode != other._collectMode:
-         if self._collectMode < other._collectMode:
+      if self.collectMode != other.collectMode:
+         if self.collectMode < other.collectMode:
             return -1
          else:
             return 1
-      if self._compressMode != other._compressMode:
-         if self._compressMode < other._compressMode:
+      if self.compressMode != other.compressMode:
+         if self.compressMode < other.compressMode:
             return -1
          else:
             return 1
-      if self._relativeExcludePaths != other._relativeExcludePaths:
-         if self._relativeExcludePaths < other._relativeExcludePaths:
+      if self.relativeExcludePaths != other.relativeExcludePaths:
+         if self.relativeExcludePaths < other.relativeExcludePaths:
             return -1
          else:
             return 1
-      if self._excludePatterns != other._excludePatterns:
-         if self._excludePatterns < other._excludePatterns:
+      if self.excludePatterns != other.excludePatterns:
+         if self.excludePatterns < other.excludePatterns:
             return -1
          else:
             return 1
@@ -381,23 +381,23 @@ class Repository(object):
       """
       if other is None:
          return 1
-      if self._repositoryType != other._repositoryType:
-         if self._repositoryType < other._repositoryType:
+      if self.repositoryType != other.repositoryType:
+         if self.repositoryType < other.repositoryType:
             return -1
          else:
             return 1
-      if self._repositoryPath != other._repositoryPath:
-         if self._repositoryPath < other._repositoryPath:
+      if self.repositoryPath != other.repositoryPath:
+         if self.repositoryPath < other.repositoryPath:
             return -1
          else:
             return 1
-      if self._collectMode != other._collectMode:
-         if self._collectMode < other._collectMode:
+      if self.collectMode != other.collectMode:
+         if self.collectMode < other.collectMode:
             return -1
          else:
             return 1
-      if self._compressMode != other._compressMode:
-         if self._compressMode < other._compressMode:
+      if self.compressMode != other.compressMode:
+         if self.compressMode < other.compressMode:
             return -1
          else:
             return 1
@@ -543,23 +543,23 @@ class SubversionConfig(object):
       """
       if other is None:
          return 1
-      if self._collectMode != other._collectMode:
-         if self._collectMode < other._collectMode:
+      if self.collectMode != other.collectMode:
+         if self.collectMode < other.collectMode:
             return -1
          else:
             return 1
-      if self._compressMode != other._compressMode:
-         if self._compressMode < other._compressMode:
+      if self.compressMode != other.compressMode:
+         if self.compressMode < other.compressMode:
             return -1
          else:
             return 1
-      if self._repositories != other._repositories:
-         if self._repositories < other._repositories:
+      if self.repositories != other.repositories:
+         if self.repositories < other.repositories:
             return -1
          else:
             return 1
-      if self._repositoryDirs != other._repositoryDirs:
-         if self._repositoryDirs < other._repositoryDirs:
+      if self.repositoryDirs != other.repositoryDirs:
+         if self.repositoryDirs < other.repositoryDirs:
             return -1
          else:
             return 1
@@ -741,8 +741,8 @@ class LocalConfig(object):
       """
       if other is None:
          return 1
-      if self._subversion != other._subversion:
-         if self._subversion < other._subversion:
+      if self.subversion != other.subversion:
+         if self.subversion < other.subversion:
             return -1
          else:
             return 1
@@ -852,6 +852,7 @@ class LocalConfig(object):
       (xmlDom, parentNode) = createInputDom(xmlData)
       self._subversion = LocalConfig._parseSubversion(parentNode)
 
+   @staticmethod
    def _parseSubversion(parent):
       """
       Parses a subversion configuration section.
@@ -884,8 +885,8 @@ class LocalConfig(object):
          subversion.repositories = LocalConfig._parseRepositories(section)
          subversion.repositoryDirs = LocalConfig._parseRepositoryDirs(section)
       return subversion
-   _parseSubversion = staticmethod(_parseSubversion)
 
+   @staticmethod
    def _parseRepositories(parent):
       """
       Reads a list of C{Repository} objects from immediately beneath the parent.
@@ -917,8 +918,8 @@ class LocalConfig(object):
       if lst == []:
          lst = None
       return lst
-   _parseRepositories = staticmethod(_parseRepositories)
 
+   @staticmethod
    def _addRepository(xmlDom, parentNode, repository):
       """
       Adds a repository container as the next child of a parent.
@@ -946,8 +947,8 @@ class LocalConfig(object):
          addStringNode(xmlDom, sectionNode, "abs_path", repository.repositoryPath)
          addStringNode(xmlDom, sectionNode, "collect_mode", repository.collectMode)
          addStringNode(xmlDom, sectionNode, "compress_mode", repository.compressMode)
-   _addRepository = staticmethod(_addRepository)
 
+   @staticmethod
    def _parseRepositoryDirs(parent):
       """
       Reads a list of C{RepositoryDir} objects from immediately beneath the parent.
@@ -988,8 +989,8 @@ class LocalConfig(object):
       if lst == []:
          lst = None
       return lst
-   _parseRepositoryDirs = staticmethod(_parseRepositoryDirs)
 
+   @staticmethod
    def _parseExclusions(parentNode):
       """
       Reads exclusions data from immediately beneath the parent.
@@ -1013,8 +1014,8 @@ class LocalConfig(object):
          relative = readStringList(section, "rel_path")
          patterns = readStringList(section, "pattern")
          return (relative, patterns)
-   _parseExclusions = staticmethod(_parseExclusions) 
 
+   @staticmethod
    def _addRepositoryDir(xmlDom, parentNode, repositoryDir):
       """
       Adds a repository dir container as the next child of a parent.
@@ -1056,7 +1057,6 @@ class LocalConfig(object):
             if repositoryDir.excludePatterns is not None:
                for pattern in repositoryDir.excludePatterns:
                   addStringNode(xmlDom, excludeNode, "pattern", pattern)
-   _addRepositoryDir = staticmethod(_addRepositoryDir)
 
 
 ########################################################################
@@ -1460,7 +1460,7 @@ def backupBDBRepository(repositoryPath, backupFile, startRevision=None, endRevis
    Backs up an individual Subversion BDB repository.
    This function is deprecated.  Use L{backupRepository} instead.
    """
-   return backupRepository(repositoryPath, backupFile, startRevision, endRevision);
+   return backupRepository(repositoryPath, backupFile, startRevision, endRevision)
 
 
 def backupFSFSRepository(repositoryPath, backupFile, startRevision=None, endRevision=None):
@@ -1468,5 +1468,5 @@ def backupFSFSRepository(repositoryPath, backupFile, startRevision=None, endRevi
    Backs up an individual Subversion FSFS repository.
    This function is deprecated.  Use L{backupRepository} instead.
    """
-   return backupRepository(repositoryPath, backupFile, startRevision, endRevision);
+   return backupRepository(repositoryPath, backupFile, startRevision, endRevision)
 
