@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: image.py 998 2010-07-07 19:56:08Z pronovic $
+# Revision : $Id: image.py 1022 2011-10-11 23:27:49Z pronovic $
 # Purpose  : Provides interface backwards compatibility.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -35,5 +35,5 @@ library interface.
 # Imported modules
 ########################################################################
 
-from CedarBackup2.writers.util import IsoImage  # pylint: disable-msg=W0611
+from CedarBackup2.writers.util import IsoImage  # pylint: disable=W0611
 
