@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2008 Kenneth J. Pronovici.
+# Copyright (c) 2004-2008,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: peer.py 947 2009-08-16 18:47:36Z pronovic $
+# Revision : $Id: peer.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Provides backup peer-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -56,11 +56,10 @@ Provides backup peer-related objects and utility functions.
 import os
 import logging
 import shutil
-import re
 
 # Cedar Backup modules
 from CedarBackup2.filesystem import FilesystemList
-from CedarBackup2.util import resolveCommand, executeCommand
+from CedarBackup2.util import resolveCommand, executeCommand, isRunningAsRoot
 from CedarBackup2.util import splitCommandLine, encodePath
 from CedarBackup2.config import VALID_FAILURE_MODES
 
@@ -317,6 +316,7 @@ class LocalPeer(object):
    # Private methods
    ##################
 
+   @staticmethod
    def _copyLocalDir(sourceDir, targetDir, ownership=None, permissions=None):
       """
       Copies files from the source directory to the target directory.
@@ -358,8 +358,8 @@ class LocalPeer(object):
          LocalPeer._copyLocalFile(sourceFile, targetFile, ownership, permissions)
          filesCopied += 1
       return filesCopied
-   _copyLocalDir = staticmethod(_copyLocalDir)
 
+   @staticmethod
    def _copyLocalFile(sourceFile=None, targetFile=None, ownership=None, permissions=None, overwrite=True):
       """
       Copies a source file to a target file.
@@ -415,7 +415,6 @@ class LocalPeer(object):
          os.chown(targetFile, ownership[0], ownership[1])
       if permissions is not None:
          os.chmod(targetFile, permissions)
-   _copyLocalFile = staticmethod(_copyLocalFile)
 
 
 ########################################################################
@@ -917,6 +916,7 @@ class RemotePeer(object):
    # Private methods
    ##################
 
+   @staticmethod
    def _getDirContents(path):
       """
       Returns the contents of a directory in terms of a Set.
@@ -939,8 +939,8 @@ class RemotePeer(object):
       except:
          import sets
          return sets.Set(contents)
-   _getDirContents = staticmethod(_getDirContents)
 
+   @staticmethod
    def _copyRemoteDir(remoteUser, localUser, remoteHost, rcpCommand, rcpCommandList, 
                       sourceDir, targetDir, ownership=None, permissions=None):
       """
@@ -1011,7 +1011,7 @@ class RemotePeer(object):
       beforeSet = RemotePeer._getDirContents(targetDir)
       if localUser is not None:
          try:
-            if os.getuid() != 0:
+            if not isRunningAsRoot():
                raise IOError("Only root can remote copy as another user.")
          except AttributeError: pass
          actualCommand = "%s %s@%s:%s/* %s" % (rcpCommand, remoteUser, remoteHost, sourceDir, targetDir)
@@ -1037,8 +1037,8 @@ class RemotePeer(object):
          if permissions is not None:
             os.chmod(targetFile, permissions)
       return len(differenceSet)
-   _copyRemoteDir = staticmethod(_copyRemoteDir)
 
+   @staticmethod
    def _copyRemoteFile(remoteUser, localUser, remoteHost, 
                        rcpCommand, rcpCommandList,
                        sourceFile, targetFile, ownership=None, 
@@ -1104,7 +1104,7 @@ class RemotePeer(object):
             raise IOError("Target file [%s] already exists." % targetFile)
       if localUser is not None:
          try:
-            if os.getuid() != 0:
+            if not isRunningAsRoot():
                raise IOError("Only root can remote copy as another user.")
          except AttributeError: pass
          actualCommand = "%s %s@%s:%s %s" % (rcpCommand, remoteUser, remoteHost, sourceFile.replace(" ", "\\ "), targetFile)
@@ -1124,8 +1124,8 @@ class RemotePeer(object):
          os.chown(targetFile, ownership[0], ownership[1])
       if permissions is not None:
          os.chmod(targetFile, permissions)
-   _copyRemoteFile = staticmethod(_copyRemoteFile)
 
+   @staticmethod
    def _pushLocalFile(remoteUser, localUser, remoteHost, 
                       rcpCommand, rcpCommandList,
                       sourceFile, targetFile, overwrite=True):
@@ -1175,7 +1175,7 @@ class RemotePeer(object):
             raise IOError("Target file [%s] already exists." % targetFile)
       if localUser is not None:
          try:
-            if os.getuid() != 0:
+            if not isRunningAsRoot():
                raise IOError("Only root can remote copy as another user.")
          except AttributeError: pass
          actualCommand = '%s "%s" "%s@%s:%s"' % (rcpCommand, sourceFile, remoteUser, remoteHost, targetFile)
@@ -1189,8 +1189,8 @@ class RemotePeer(object):
          result = executeCommand(command, [sourceFile.replace(" ", "\\ "), copyTarget])[0]
          if result != 0:
             raise IOError("Error (%d) copying [%s] to remote host." % (result, sourceFile))
-   _pushLocalFile = staticmethod(_pushLocalFile)
 
+   @staticmethod
    def _executeRemoteCommand(remoteUser, localUser, remoteHost, rshCommand, rshCommandList, remoteCommand):
       """
       Executes a command on the peer via remote shell.
@@ -1218,7 +1218,7 @@ class RemotePeer(object):
       actualCommand = "%s %s@%s '%s'" % (rshCommand, remoteUser, remoteHost, remoteCommand)
       if localUser is not None:
          try:
-            if os.getuid() != 0:
+            if not isRunningAsRoot():
                raise IOError("Only root can remote shell as another user.")
          except AttributeError: pass
          command = resolveCommand(SU_COMMAND) 
@@ -1230,8 +1230,8 @@ class RemotePeer(object):
          result = executeCommand(command, ["%s@%s" % (remoteUser, remoteHost), "%s" % remoteCommand])[0]
          if result != 0:
             raise IOError("Command failed [%s]" % (actualCommand))
-   _executeRemoteCommand = staticmethod(_executeRemoteCommand)
 
+   @staticmethod
    def _buildCbackCommand(cbackCommand, action, fullBackup):
       """
       Builds a Cedar Backup command line for the named action.
@@ -1253,5 +1253,4 @@ class RemotePeer(object):
          return "%s --full %s" % (cbackCommand, action)
       else:
          return "%s %s" % (cbackCommand, action)
-   _buildCbackCommand = staticmethod(_buildCbackCommand)
 
