@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1029 2013-03-21 14:38:17Z pronovic $
+# Revision : $Id: release.py 1044 2013-05-10 02:16:12Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2011,2013"
-VERSION     = "2.21.1"
-DATE        = "21 Mar 2013"
+VERSION     = "2.22.0"
+DATE        = "09 May 2013"
 URL         = "http://cedar-backup.sourceforge.net/"
 
