@@ -30,7 +30,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 1023 2011-10-11 23:44:50Z pronovic $
+# Revision : $Id: util.py 1042 2013-05-10 02:10:00Z pronovic $
 # Purpose  : Provides general-purpose utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -1453,6 +1453,9 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
    @param returnOutput: Indicates whether to return the output of the command
    @type returnOutput: Boolean C{True} or C{False}
 
+   @param ignoreStderr: Whether stderr should be discarded
+   @type ignoreStderr: Boolean True or False
+
    @param doNotLog: Indicates that output should not be logged.
    @type doNotLog: Boolean C{True} or C{False}
 
