@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2007 Kenneth J. Pronovici.
+# Copyright (c) 2004-2007,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 741 2007-03-25 16:18:22Z pronovic $
+# Revision : $Id: util.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Provides utilities related to image writers.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -52,8 +52,6 @@ import re
 import logging
 
 # Cedar Backup modules
-from CedarBackup2.filesystem import FilesystemList
-from CedarBackup2.knapsack import worstFit
 from CedarBackup2.util import resolveCommand, executeCommand
 from CedarBackup2.util import convertSize, UNIT_BYTES, UNIT_SECTORS, encodePath
 
@@ -610,6 +608,7 @@ class IsoImage(object):
    # Methods used to build mkisofs commands
    #########################################
 
+   @staticmethod
    def _buildDirEntries(entries):
       """
       Uses an entries dictionary to build a list of directory locations for use
@@ -631,7 +630,6 @@ class IsoImage(object):
          else:
             dirEntries.append("%s/=%s" % (entries[key].strip("/"), key))
       return dirEntries
-   _buildDirEntries = staticmethod(_buildDirEntries)
 
    def _buildGeneralArgs(self):
       """
