@@ -9,7 +9,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2005 Kenneth J. Pronovici.
+# Copyright (c) 2004-2005,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -26,9 +26,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: knapsackdemo.py 471 2005-10-01 17:00:57Z pronovic $
+# Revision : $Id: knapsackdemo.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Demo the knapsack functionality in knapsack.py
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -80,6 +80,8 @@ BYTES_PER_MBYTE = BYTES_PER_KBYTE * KBYTES_PER_MBYTE
 
 def main():
 
+   """Main routine."""
+
    # Check arguments
    if len(sys.argv) != 3:
       print "Usage: %s dir capacity" % sys.argv[0]
@@ -138,7 +140,7 @@ def main():
              '  ALT FIT': alternateFit } 
 
    # Run each test
-   total_elapsed = 0.0
+   totalElapsed = 0.0
    for key in tests.keys():
 
       # Run and time the test
@@ -148,20 +150,20 @@ def main():
       count = len(items)
 
       # Calculate derived values
-      count_pct = (float(count)/float(len(files))) * 100.0
-      used_pct = (float(used)/(float(capacity)*BYTES_PER_MBYTE)) * 100.0
+      countPercent = (float(count)/float(len(files))) * 100.0
+      usedPercent = (float(used)/(float(capacity)*BYTES_PER_MBYTE)) * 100.0
       elapsed = end - start
-      total_elapsed += elapsed
+      totalElapsed += elapsed
 
       # Display the results
       print "%s: %5d files (%6.2f%%), %6.2f MB (%6.2f%%), elapsed: %8.5f sec" % (
             key,
-            count, count_pct,
-            used/BYTES_PER_MBYTE, used_pct,
+            count, countPercent,
+            used/BYTES_PER_MBYTE, usedPercent,
             elapsed)
 
    # And, print the total elapsed time
-   print "\nTotal elapsed processing time was about %.3f seconds." % total_elapsed
+   print "\nTotal elapsed processing time was about %.3f seconds." % totalElapsed
 
 
 ########################################################################
